@@ -249,8 +249,6 @@ class User(db.Model):
         :return: list
         """
         needs = [RoleNeed(role.handle) for role in self.roles]
-        if self.id:
-            needs.append(UserNeed(self.id))
         return needs
 
     # -------------------------------------------------------------------------
@@ -465,4 +463,4 @@ class User(db.Model):
         )
 
         roles.append(default_role)
-        return tuple(roles)
\ No newline at end of file
+        return tuple(roles)
